/* this file needs to be converted to DTML */

.newsImage.nitf {
    cursor: pointer;
}

#media-bar {
    margin: 0 auto;
    width: 500px;
}

#media-bar .thumbnails {
    margin-bottom: 20px;
}

/* TODO: fix background URL property */
/* next/prev buttons */
.navi {
    background: url(/++resource++collective.nitf/images/hori_large.png) no-repeat;
    width: 30px;
    height: 30px;
    float: left;
    margin: 40px 5px;
}

.navi:hover {
    background-position: -30px 0;
}

.navi:active {
    background-position: -60px 0;
}

.next {
    background-position: 0 -30px;
    clear: right;
}

.next:hover {
    background-position: -30px -30px;
}

.next:active {
    background-position: -60px -30px;
}

.navi.disabled {
    visibility: hidden;
}

/******* NEWSITEM/MEDIA VIEWS *****/
#mediabox {
    background-color: #ffffff;
    border: 1px solid #D9D9D9;
    width: 500px;
    height: 500px;
/*    position: absolute;*/
    display: none;
    margin: 0 auto;
}
body.template-view #mediabox {
    box-shadow: 0 0 3em 0.5em #666666;
    -moz-box-shadow: 0 0 3em 0.5em #666666;
    -webkit-box-shadow: 0 0 3em #666666;
}

body.template-gallery #mediabox {
    display: table;
}

.mediaview #mediabox {
    display: block;
    margin-bottom: 1em;
}

#mediabox #images {
    position: absolute;
    overflow: hidden;
    margin: 50px;
    width: 400px;
    height: 400px;
}

#mediabox #images .items div {
/* float:left; */
    display: inline-block;
}

#mediabox #images .items div span,
body.template-gallery #mediabox span {
    display: table-cell;
    vertical-align: middle;
    width: 400px;
    height: 400px;
    text-align: center;
}

#mediabox #images .items img:hover {
    cursor: pointer;
}

/* next/prev buttons */
#mediabox .navi {
    clear: none;
    width: 30px;
    height: 30px;
    float: left;
    margin: 40px 5px;
    position: absolute;
    bottom: -30px;
/*
    position: absolute;
    bottom: 33px;
    left: 50px;
*/
}

#mediabox .next {
    right: 0px;
}

#mediabox #images .items .info {
    float: none;
    display: none;
    background: #333;
    color: #fff;
    font-size: 13px;
    margin: -50px 0 0 30px;
    padding: 5px 0px;
    height: 125px;
    width: 400px;
}

#mediabox #images .items .info h3 {
    color: #cde;
    margin-top: 10px;
}

#mediabox #images .items .info p {
    text-align: justify;
    font-size: 11px;
}

.navibuttons {
    display: block;
    bottom: -460px;
    position: relative;
}

/* next/prev buttons */
#mediabox .navibuttons .navi {
    clear: none;
    width: 30px;
    height: 30px;
    float: left;
    margin: 0 5px;
    position: inherit;
    bottom: auto;
/*
    position: absolute;
    bottom: 33px;
    left: 50px;
*/
}

#mediabox .navibuttons .next {
    float: right;
}

/* used in media_sorter.pt */
.sortable-media {
    list-style-type: none !important;
    margin: 0 !important;
    padding: 0;
}

.sortable-media li {
    border: 1px solid silver;
    float: left;
    height: 128px;
    margin: 0 10px 10px 0;
    padding: 4px;
    width: 128px;
    background-color:#FFF;
    position:relative;
}
.sortable-media li:hover .button{
    visibility:visible;
}
.sortable-media .draggable-item {
    cursor: move;
    height: 90px;
    overflow: hidden;
    display: block;
    border:medium none;
    }

.sortable-media .button,
.sortable-media .button:hover {
    color:#FFF !important;
    padding:3px 10px 3px 5px;
    float:right;
    margin-top:6px;
    background-color:#999;
}
    
.sortable-media .button{
    visibility:hidden;
    right: 0px;
}
.button .icon {
    height: 15px;
    width:13px;
    float:left;

}
.button.edit {
    background: none repeat scroll 0 0 #75AD0A;
}
.button.edit .icon{
    background: url("/++resource++collective.nitf/images/icons-media.png") no-repeat scroll 0px top transparent;
    line-height: 50px;
    margin-right: 5px;
    margin-top: 4px;
}
.button.delete {
    position:absolute;
    top:0px;
    right:0px;
    background-color: #C43C35;
}
.button.delete .icon{
    background: url("/++resource++collective.nitf/images/icons-media.png") no-repeat scroll -15px top transparent;
    line-height: 50px;
    margin-right: 5px;
}